summaryrefslogtreecommitdiffstats
path: root/vespajlib
diff options
context:
space:
mode:
authorJon Marius Venstad <venstad@gmail.com>2020-12-10 08:01:50 +0100
committerJon Marius Venstad <venstad@gmail.com>2020-12-10 08:01:50 +0100
commit06803b97348d9a4fb56df083cae73e2afbc44438 (patch)
tree82fd0d35de85fd05c03df9cd1c041969778664b8 /vespajlib
parentc8f8e85351b70a02b9915b6978dd05e1c2cc55c7 (diff)
Rename close to awaitShutdown
Diffstat (limited to 'vespajlib')
-rw-r--r--vespajlib/src/main/java/com/yahoo/concurrent/maintenance/Maintainer.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/vespajlib/src/main/java/com/yahoo/concurrent/maintenance/Maintainer.java b/vespajlib/src/main/java/com/yahoo/concurrent/maintenance/Maintainer.java
index 2bf91775ecc..2690edc9407 100644
--- a/vespajlib/src/main/java/com/yahoo/concurrent/maintenance/Maintainer.java
+++ b/vespajlib/src/main/java/com/yahoo/concurrent/maintenance/Maintainer.java
@@ -62,14 +62,14 @@ public abstract class Maintainer implements Runnable {
log.log(Level.FINE, () -> "Finished " + this.getClass().getSimpleName());
}
/** Starts shutdown of this, typically by shutting down executors. {@link #close()} waits for shutdown to complete. */
public void shutdown() {
if ( ! shutDown.getAndSet(true))
service.shutdown();
}
/** Waits for shutdown to complete, calling {@link #shutdown} if this hasn't been done already. */
- public void close() {
+ public void awaitShutdown() {
shutdown();
var timeout = Duration.ofSeconds(30);
try {
@@ -62,14 +62,14 @@ public abstract class Maintainer implements Runnable {
log.log(Level.FINE, () -> "Finished " + this.getClass().getSimpleName());
}
- /** Starts shutdown of this, typically by shutting down executors. {@link #close()} waits for shutdown to complete. */
+ /** Starts shutdown of this, typically by shutting down executors. {@link #awaitShutdown()} waits for shutdown to complete. */
public void shutdown() {
if ( ! shutDown.getAndSet(true))